KePrompt - Web Interface

## Conversations

Loading chats...

## 💬 Select a chat to start

Choose a conversation from the list or create a new one

### Chat

## Prompts

Loading prompts...

## 📝 Select a prompt to view

Choose a prompt from the list to see its details

### Prompt Name

## 🤖 AI Models

Loading models...

## 🔌 API Providers

Loading providers...

## ⚙️ Available Functions

Loading functions...

## 💾 Database Management

Loading database info...

## 🖥️ Server Status

Loading server info...

## Create New Chat

Select Prompt:
Parameters:

## Confirm Action

Are you sure?